==> qtjambi-nfc-debuginfo-macos-5.15.20.jar: sources/QtJambiNfc/QNearFieldTarget_RequestId_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtNfc/qnearfieldtarget.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambiNfc/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QNearFieldTarget_RequestId(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QNearFieldTarget::RequestId")
    QNearFieldTarget::RequestId *_ptr = reinterpret_cast<QNearFieldTarget::RequestId *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new RequestId()
void __qt_construct_QNearFieldTarget_RequestId(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct RequestId()")
    Q_UNUSED(__java_arguments)
    QNearFieldTarget::RequestId *__qt_this = new(__qtjambi_ptr) QNearFieldTarget::RequestId();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QNearFieldTarget::RequestId::RequestId()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_nfc_QNearFieldTarget_00024RequestId_initialize_1native__Lio_qt_nfc_QNearFieldTarget_00024RequestId_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QNearFieldTarget::RequestId::RequestId()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QNearFieldTarget_RequestId, sizeof(QNearFieldTarget::RequestId), typeid(QNearFieldTarget::RequestId), false, &deleter_QNearFieldTarget_RequestId, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new RequestId(QNearFieldTarget::RequestId)
void __qt_construct_QNearFieldTarget_RequestId_cref_QNearFieldTarget_RequestId(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct RequestId(QNearFieldTarget::RequestId)")
    jobject other0 = __java_arguments[0].l;
    const QNearFieldTarget::RequestId& __qt_other0 = qtjambi_cast<const QNearFieldTarget::RequestId& >(__jni_env, other0);
    QNearFieldTarget::RequestId *__qt_this = new(__qtjambi_ptr) QNearFieldTarget::RequestId(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QNearFieldTarget::RequestId::RequestId(QNearFieldTarget::RequestId)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_nfc_QNearFieldTarget_00024RequestId_initialize_1native__Lio_qt_nfc_QNearFieldTarget_00024RequestId_2Lio_qt_nfc_QNearFieldTarget_00024RequestId_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QNearFieldTarget::RequestId::RequestId(QNearFieldTarget::RequestId)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QNearFieldTarget_RequestId_cref_QNearFieldTarget_RequestId, sizeof(QNearFieldTarget::RequestId), typeid(QNearFieldTarget::RequestId), false, &deleter_QNearFieldTarget_RequestId, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QNearFieldTarget::RequestId
void __qt_destruct_QNearFieldTarget_RequestId(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QNearFieldTarget::RequestId")
    reinterpret_cast<QNearFieldTarget::RequestId*>(ptr)->~RequestId();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QNearFieldTarget::RequestId::isValid()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_nfc_QNearFieldTarget_00024RequestId_isValid_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QNearFieldTarget::RequestId *__qt_this = QtJambiAPI::objectFromNativeId<QNearFieldTarget::RequestId>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QNearFieldTarget::RequestId::isValid()const", __qt_this)
        __java_return_value = __qt_this->isValid();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QNearFieldTarget::RequestId::operator<(QNearFieldTarget::RequestId)const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_nfc_QNearFieldTarget_00024RequestId_operator_1less_1native_1cref_1QNearFieldTarget_1RequestId_1constfct__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QNearFieldTarget::RequestId *__qt_this = QtJambiAPI::objectFromNativeId<QNearFieldTarget::RequestId>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QNearFieldTarget::RequestId::operator<(QNearFieldTarget::RequestId)const", __qt_this)
        const QNearFieldTarget::RequestId& __qt_other0 = QtJambiAPI::valueReferenceFromNativeId<QNearFieldTarget::RequestId>(other0);
        __java_return_value = (*__qt_this) < __qt_other0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QNearFieldTarget::RequestId::operator=(QNearFieldTarget::RequestId)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_nfc_QNearFieldTarget_00024RequestId_assign_1native_1cref_1QNearFieldTarget_1RequestId__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QNearFieldTarget::RequestId *__qt_this = QtJambiAPI::objectFromNativeId<QNearFieldTarget::RequestId>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QNearFieldTarget::RequestId::operator=(QNearFieldTarget::RequestId)", __qt_this)
        const QNearFieldTarget::RequestId& __qt_other0 = QtJambiAPI::valueReferenceFromNativeId<QNearFieldTarget::RequestId>(other0);
        (*__qt_this) = __qt_other0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QNearFieldTarget::RequestId::operator==(QNearFieldTarget::RequestId)const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_nfc_QNearFieldTarget_00024RequestId_equals_1native_1cref_1QNearFieldTarget_1RequestId_1constfct__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QNearFieldTarget::RequestId *__qt_this = QtJambiAPI::objectFromNativeId<QNearFieldTarget::RequestId>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QNearFieldTarget::RequestId::operator==(QNearFieldTarget::RequestId)const", __qt_this)
        const QNearFieldTarget::RequestId& __qt_other0 = QtJambiAPI::valueReferenceFromNativeId<QNearFieldTarget::RequestId>(other0);
        __java_return_value = (*__qt_this) == __qt_other0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QNearFieldTarget::RequestId::refCount()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_nfc_QNearFieldTarget_00024RequestId_refCount_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QNearFieldTarget::RequestId *__qt_this = QtJambiAPI::objectFromNativeId<QNearFieldTarget::RequestId>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QNearFieldTarget::RequestId::refCount()const", __qt_this)
        __java_return_value = __qt_this->refCount();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_nfc_QNearFieldTarget_00024RequestId_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QNearFieldTarget::RequestId *__qt_this = QtJambiAPI::objectFromNativeId<QNearFieldTarget::RequestId>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(hashValue);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_nfc_QNearFieldTarget_00024RequestId_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QNearFieldTarget::RequestId *__qt_this = QtJambiAPI::objectFromNativeId<QNearFieldTarget::RequestId>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QNearFieldTarget_RequestId(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QNearFieldTarget::RequestId>("QNearFieldTarget::RequestId", "io/qt/nfc/QNearFieldTarget$RequestId");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QNearFieldTarget_RequestId, {
        ConstructorInfo(&__qt_construct_QNearFieldTarget_RequestId, nullptr)
       ,ConstructorInfo(&__qt_construct_QNearFieldTarget_RequestId_cref_QNearFieldTarget_RequestId, "Lio/qt/nfc/QNearFieldTarget$RequestId;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QNearFieldTarget_RequestId);
    registerMetaType<QNearFieldTarget::RequestId>("QNearFieldTarget::RequestId");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-nfc-debuginfo-macos-6.5.4.jar: sources/QtJambiNfc/QNearFieldTarget_RequestId_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtNfc/qnearfieldtarget.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambiNfc/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QNearFieldTarget_RequestId(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QNearFieldTarget::RequestId")
    QNearFieldTarget::RequestId *_ptr = reinterpret_cast<QNearFieldTarget::RequestId *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new RequestId()
void __qt_construct_QNearFieldTarget_RequestId_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct RequestId()")
    Q_UNUSED(__java_arguments)
    QNearFieldTarget::RequestId *__qt_this = new(__qtjambi_ptr) QNearFieldTarget::RequestId();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// new RequestId(QNearFieldTarget::RequestId)
void __qt_construct_QNearFieldTarget_RequestId_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct RequestId(QNearFieldTarget::RequestId)")
    jobject other0 = __java_arguments[0].l;
    const QNearFieldTarget::RequestId& __qt_other0 = qtjambi_cast<const QNearFieldTarget::RequestId& >(__jni_env, other0);
    QNearFieldTarget::RequestId *__qt_this = new(__qtjambi_ptr) QNearFieldTarget::RequestId(__qt_other0);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QNearFieldTarget::RequestId
void __qt_destruct_QNearFieldTarget_RequestId(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QNearFieldTarget::RequestId")
    reinterpret_cast<QNearFieldTarget::RequestId*>(ptr)->~RequestId();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QNearFieldTarget::RequestId::RequestId()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_nfc_QNearFieldTarget_00024RequestId_initialize_1native__Lio_qt_nfc_QNearFieldTarget_00024RequestId_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QNearFieldTarget::RequestId::RequestId()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QNearFieldTarget_RequestId_0, sizeof(QNearFieldTarget::RequestId), typeid(QNearFieldTarget::RequestId), false, &deleter_QNearFieldTarget_RequestId, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QNearFieldTarget::RequestId::RequestId(QNearFieldTarget::RequestId)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_nfc_QNearFieldTarget_00024RequestId_initialize_1native__Lio_qt_nfc_QNearFieldTarget_00024RequestId_2Lio_qt_nfc_QNearFieldTarget_00024RequestId_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QNearFieldTarget::RequestId::RequestId(QNearFieldTarget::RequestId)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QNearFieldTarget_RequestId_1, sizeof(QNearFieldTarget::RequestId), typeid(QNearFieldTarget::RequestId), false, &deleter_QNearFieldTarget_RequestId, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QNearFieldTarget::RequestId::isValid()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_nfc_QNearFieldTarget_00024RequestId_isValid_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QNearFieldTarget::RequestId *__qt_this = QtJambiAPI::objectFromNativeId<QNearFieldTarget::RequestId>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QNearFieldTarget::RequestId::isValid()const", __qt_this)
        __java_return_value = __qt_this->isValid();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QNearFieldTarget::RequestId::operator<(QNearFieldTarget::RequestId)const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_nfc_QNearFieldTarget_00024RequestId_operator_1less_1native_1cref_1QNearFieldTarget_1RequestId_1constfct__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QNearFieldTarget::RequestId *__qt_this = QtJambiAPI::objectFromNativeId<QNearFieldTarget::RequestId>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QNearFieldTarget::RequestId::operator<(QNearFieldTarget::RequestId)const", __qt_this)
        const QNearFieldTarget::RequestId& __qt_other0 = QtJambiAPI::valueReferenceFromNativeId<QNearFieldTarget::RequestId>(other0);
        __java_return_value = (*__qt_this) < __qt_other0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QNearFieldTarget::RequestId::operator=(QNearFieldTarget::RequestId)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_nfc_QNearFieldTarget_00024RequestId_assign_1native_1cref_1QNearFieldTarget_1RequestId__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QNearFieldTarget::RequestId *__qt_this = QtJambiAPI::objectFromNativeId<QNearFieldTarget::RequestId>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QNearFieldTarget::RequestId::operator=(QNearFieldTarget::RequestId)", __qt_this)
        const QNearFieldTarget::RequestId& __qt_other0 = QtJambiAPI::valueReferenceFromNativeId<QNearFieldTarget::RequestId>(other0);
        (*__qt_this) = __qt_other0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QNearFieldTarget::RequestId::operator==(QNearFieldTarget::RequestId)const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_nfc_QNearFieldTarget_00024RequestId_equals_1native_1cref_1QNearFieldTarget_1RequestId_1constfct__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QNearFieldTarget::RequestId *__qt_this = QtJambiAPI::objectFromNativeId<QNearFieldTarget::RequestId>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QNearFieldTarget::RequestId::operator==(QNearFieldTarget::RequestId)const", __qt_this)
        const QNearFieldTarget::RequestId& __qt_other0 = QtJambiAPI::valueReferenceFromNativeId<QNearFieldTarget::RequestId>(other0);
        __java_return_value = (*__qt_this) == __qt_other0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QNearFieldTarget::RequestId::refCount()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_nfc_QNearFieldTarget_00024RequestId_refCount_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QNearFieldTarget::RequestId *__qt_this = QtJambiAPI::objectFromNativeId<QNearFieldTarget::RequestId>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QNearFieldTarget::RequestId::refCount()const", __qt_this)
        __java_return_value = __qt_this->refCount();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_nfc_QNearFieldTarget_00024RequestId_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QNearFieldTarget::RequestId *__qt_this = QtJambiAPI::objectFromNativeId<QNearFieldTarget::RequestId>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(quint64(hashValue) ^ quint64(hashValue) >> 32);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_nfc_QNearFieldTarget_00024RequestId_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QNearFieldTarget::RequestId *__qt_this = QtJambiAPI::objectFromNativeId<QNearFieldTarget::RequestId>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QNearFieldTarget_RequestId(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QNearFieldTarget::RequestId>("QNearFieldTarget::RequestId", "io/qt/nfc/QNearFieldTarget$RequestId");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QNearFieldTarget_RequestId, {
        ConstructorInfo(&__qt_construct_QNearFieldTarget_RequestId_0, nullptr)
       ,ConstructorInfo(&__qt_construct_QNearFieldTarget_RequestId_1, "Lio/qt/nfc/QNearFieldTarget$RequestId;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QNearFieldTarget_RequestId);
    registerMetaType<QNearFieldTarget::RequestId>("QNearFieldTarget::RequestId");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
